# ReColonyzer

[![Travis (.org)](https://img.shields.io/travis/judithbergada/recolonyzer?style=for-the-badge)](https://travis-ci.org/judithbergada/recolonyzer) [![PyPI](https://img.shields.io/pypi/v/recolonyzer?style=for-the-badge)](https://pypi.org/project/recolonyzer/) [![PyPI - License](https://img.shields.io/pypi/l/recolonyzer?style=for-the-badge)](https://github.com/judithbergada/recolonyzer/blob/master/LICENSE)
